==> verttice_ui-0.0.43.tar.gz: lib/src/widgets/themed_editor/themed_editor.dart <==
import 'dart:async';
import 'package:collection/collection.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_quill/flutter_quill.dart' hide Text;
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/verttice_ui.dart';

import 'editor_universal_ui/universal_ui.dart';
import 'files_manager.dart';

class ThemedEditor extends StatefulWidget {
  final List<dynamic>? jsonContect;
  final List<FileModel>? files;
  final String? pathToStoreMedia;
  final bool readonly;
  final Future<void> Function({required List<dynamic> jsonContect})?
      fileContentCallback;
  final Future<void> Function({required List<FileModel> files})?
      filesDataCallback;
  const ThemedEditor({
    Key? key,
    this.jsonContect,
    this.files,
    this.readonly = false,
    this.fileContentCallback,
    this.pathToStoreMedia,
    this.filesDataCallback,
  }) : super(key: key);

  @override
  _EditorState createState() => _EditorState();
}

class _EditorState extends State<ThemedEditor> {
  List<dynamic>? _jsonContect;
  QuillController? _controller;
  List<FileModel>? _files;
  final FocusNode _focusNode = FocusNode();

  @override
  void initState() {
    super.initState();
    _files = widget.files;
    _jsonContect = widget.jsonContect;
    if (_jsonContect != null && _jsonContect!.isNotEmpty) {
      _controller = QuillController(
        document: Document.fromJson(_jsonContect!),
        selection: const TextSelection.collapsed(offset: 0),
      );
    } else {
      _controller = QuillController.basic();
    }
  }

  @override
  void didUpdateWidget(covariant ThemedEditor oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const DeepCollectionEquality().equals(_files, widget.files)) {
      _files = widget.files;
    }
    if (!const DeepCollectionEquality()
        .equals(_jsonContect, widget.jsonContect)) {
      _jsonContect = widget.jsonContect;
      if (_jsonContect != null && _jsonContect!.isNotEmpty) {
        _controller = QuillController(
          document: Document.fromJson(_jsonContect!),
          selection: const TextSelection.collapsed(offset: 0),
        );
      } else {
        _controller = QuillController.basic();
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    if (_controller == null) {
      return const Scaffold(body: Center(child: Text('Loading...')));
    }

    var quillEditor = QuillEditor(
      controller: _controller!,
      scrollController: ScrollController(),
      scrollable: true,
      focusNode: _focusNode,
      autoFocus: false,
      readOnly: widget.readonly,
      placeholder: 'Write here...',
      expands: false,
      padding: EdgeInsets.zero,
    );
    if (kIsWeb) {
      quillEditor = QuillEditor(
        controller: _controller!,
        scrollController: ScrollController(),
        scrollable: false,
        focusNode: _focusNode,
        autoFocus: false,
        readOnly: widget.readonly,
        placeholder: 'Write here...',
        expands: false,
        padding: EdgeInsets.zero,
        embedBuilder: defaultEmbedBuilderWeb,
      );
    }
    var toolbar = QuillToolbar.basic(
      controller: _controller!,
      showAlignmentButtons: true,
      showImageButton: true,
      showVideoButton: true,
    );

    return Scaffold(
      floatingActionButton: widget.fileContentCallback == null
          ? null
          : FloatingActionButton(
              onPressed: () async {
                if (_controller != null) {
                  widget.fileContentCallback!(
                    jsonContect: _controller!.document.toDelta().toJson(),
                  );
                }
              },
              child: ThemedIcons.check(),
            ),
      body: SafeArea(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            widget.readonly
                ? const SizedBox()
                : Row(
                    children: [
                      if (widget.filesDataCallback != null)
                        ThemedEditorFilesManeger(
                          files: _files ?? [],
                          path: widget.pathToStoreMedia ?? "editorFiles",
                          filesDataCallback: (files) async {
                            await widget.filesDataCallback!(files: files);
                          },
                        ),
                      if (kIsWeb)
                        Expanded(
                          child: Container(
                            padding: const EdgeInsets.symmetric(
                                vertical: 16, horizontal: 8),
                            child: toolbar,
                          ),
                        )
                      else
                        Expanded(child: Container(child: toolbar)),
                    ],
                  ),
            const SizedBox(
              height: 8,
            ),
            Expanded(
              flex: 15,
              child: Container(
                color: Colors.white,
                padding: const EdgeInsets.only(left: 16, right: 16),
                child: quillEditor,
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> verttice_ui-0.0.47.tar.gz: lib/src/widgets/themed_editor/themed_editor.dart <==
import 'dart:async';
import 'package:collection/collection.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_quill/flutter_quill.dart' hide Text;
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/verttice_ui.dart';

import 'editor_universal_ui/universal_ui.dart';
import 'files_manager.dart';

class ThemedEditor extends StatefulWidget {
  final List<dynamic>? jsonContect;
  final List<FileModel>? files;
  final String? pathToStoreMedia;
  final bool readonly;
  final Future<void> Function({required List<dynamic> jsonContect})?
      fileContentCallback;
  final Future<void> Function({required List<FileModel> files})?
      filesDataCallback;
  const ThemedEditor({
    Key? key,
    this.jsonContect,
    this.files,
    this.readonly = false,
    this.fileContentCallback,
    this.pathToStoreMedia,
    this.filesDataCallback,
  }) : super(key: key);

  @override
  _EditorState createState() => _EditorState();
}

class _EditorState extends State<ThemedEditor> {
  List<dynamic>? _jsonContect;
  QuillController? _controller;
  List<FileModel>? _files;
  final FocusNode _focusNode = FocusNode();

  @override
  void initState() {
    super.initState();
    _files = widget.files;
    _jsonContect = widget.jsonContect;
    if (_jsonContect != null && _jsonContect!.isNotEmpty) {
      _controller = QuillController(
        document: Document.fromJson(_jsonContect!),
        selection: const TextSelection.collapsed(offset: 0),
      );
    } else {
      _controller = QuillController.basic();
    }
  }

  @override
  void didUpdateWidget(covariant ThemedEditor oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const DeepCollectionEquality().equals(_files, widget.files)) {
      _files = widget.files;
    }
    if (!const DeepCollectionEquality()
        .equals(_jsonContect, widget.jsonContect)) {
      _jsonContect = widget.jsonContect;
      if (_jsonContect != null && _jsonContect!.isNotEmpty) {
        _controller = QuillController(
          document: Document.fromJson(_jsonContect!),
          selection: const TextSelection.collapsed(offset: 0),
        );
      } else {
        _controller = QuillController.basic();
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    if (_controller == null) {
      return const Scaffold(body: Center(child: Text('Loading...')));
    }

    var quillEditor = QuillEditor(
      controller: _controller!,
      scrollController: ScrollController(),
      scrollable: widget.readonly ? false : true,
      focusNode: _focusNode,
      autoFocus: false,
      readOnly: widget.readonly,
      placeholder: 'Write here...',
      expands: false,
      padding: EdgeInsets.zero,
    );
    if (kIsWeb) {
      quillEditor = QuillEditor(
        controller: _controller!,
        scrollController: ScrollController(),
        scrollable: widget.readonly ? false : true,
        focusNode: _focusNode,
        autoFocus: false,
        readOnly: widget.readonly,
        placeholder: 'Write here...',
        expands: false,
        padding: const EdgeInsets.all(4),
        embedBuilder: defaultEmbedBuilderWeb,
      );
    }
    var toolbar = QuillToolbar.basic(
      controller: _controller!,
      showAlignmentButtons: true,
      showImageButton: true,
      showVideoButton: true,
    );

    return Scaffold(
      floatingActionButton: widget.fileContentCallback == null
          ? null
          : FloatingActionButton(
              onPressed: () async {
                if (_controller != null) {
                  widget.fileContentCallback!(
                    jsonContect: _controller!.document.toDelta().toJson(),
                  );
                }
              },
              child: ThemedIcons.check(),
            ),
      body: SafeArea(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            if (!widget.readonly)
              Row(
                children: [
                  if (widget.filesDataCallback != null)
                    ThemedEditorFilesManeger(
                      files: _files ?? [],
                      path: widget.pathToStoreMedia ?? "editorFiles",
                      filesDataCallback: (files) async {
                        await widget.filesDataCallback!(files: files);
                      },
                    ),
                  Expanded(
                    child: Container(
                      padding: !kIsWeb
                          ? null
                          : const EdgeInsets.symmetric(
                              vertical: 16,
                              horizontal: 8,
                            ),
                      child: toolbar,
                    ),
                  )
                ],
              ),
            const SizedBox(
              height: 8,
            ),
            if (widget.readonly)
              Container(
                color: Colors.white,
                padding: const EdgeInsets.only(left: 16, right: 16),
                child: quillEditor,
              )
            else
              Expanded(
                flex: 15,
                child: Container(
                  color: Colors.white,
                  padding: const EdgeInsets.only(left: 16, right: 16),
                  child: quillEditor,
                ),
              ),
          ],
        ),
      ),
    );
  }
}
